@@ -1,5 +1,5 @@
 //! Extended utilities for working with files and filesystems in Rust.
-#![doc(html_root_url = "https://docs.rs/fs4/0.8.4")]
+#![doc(html_root_url = "https://docs.rs/fs4/0.11.0")]
 #![cfg_attr(test, feature(test))]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![cfg_attr(docsrs, allow(unused_attributes))]
@@ -18,6 +18,28 @@ macro_rules! cfg_async_std {
     }
 }
 
+// This lint is a bug, it is being used in multiple places.
+#[allow(unused_macros)]
+macro_rules! cfg_fs_err {
+    ($($item:item)*) => {
+        $(
+            #[cfg(feature = "fs-err")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "fs-err")))]
+            $item
+        )*
+    }
+}
+
+macro_rules! cfg_fs_err_tokio {
+    ($($item:item)*) => {
+        $(
+            #[cfg(feature = "fs-err-tokio")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "fs-err-tokio")))]
+            $item
+        )*
+    }
+}
+
 macro_rules! cfg_smol {
     ($($item:item)*) => {
         $(
@@ -39,10 +61,20 @@ macro_rules! cfg_tokio {
 }
 
 macro_rules! cfg_sync {
+  ($($item:item)*) => {
+      $(
+          #[cfg(feature = "sync")]
+          #[cfg_attr(docsrs, doc(cfg(feature = "sync")))]
+          $item
+      )*
+  }
+}
+
+macro_rules! cfg_fs_err {
     ($($item:item)*) => {
         $(
-            #[cfg(feature = "sync")]
-            #[cfg_attr(docsrs, doc(cfg(feature = "sync")))]
+            #[cfg(feature = "fs-err")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "fs-err")))]
             $item
         )*
     }
@@ -51,8 +83,8 @@ macro_rules! cfg_sync {
 macro_rules! cfg_async {
     ($($item:item)*) => {
         $(
-            #[cfg(any(feature = "smol", feature = "async-std", feature = "tokio"))]
-            #[cfg_attr(docsrs, doc(cfg(any(feature = "smol", feature = "async-std", feature = "tokio"))))]
+            #[cfg(any(feature = "smol", feature = "async-std", feature = "tokio", feature = "fs-err-tokio"))]
+            #[cfg_attr(docsrs, doc(cfg(any(feature = "smol", feature = "async-std", feature = "tokio", feature = "fs-err-tokio"))))]
             $item
         )*
     }
@@ -70,8 +102,18 @@ mod windows;
 use windows as sys;
 
 mod file_ext;
-#[cfg(feature = "sync")]
-pub use file_ext::FileExt;
+
+cfg_sync!(
+    pub mod fs_std {
+        pub use crate::file_ext::sync_impl::std_impl::FileExt;
+    }
+);
+
+cfg_fs_err!(
+    pub mod fs_err {
+        pub use crate::file_ext::sync_impl::fs_err_impl::FileExt;
+    }
+);
 
 cfg_async_std!(
     pub mod async_std {
@@ -79,6 +121,12 @@ cfg_async_std!(
     }
 );
 
+cfg_fs_err_tokio!(
+    pub mod fs_err_tokio {
+        pub use crate::file_ext::async_impl::fs_err_tokio_impl::AsyncFileExt;
+    }
+);
+
 cfg_smol!(
     pub mod smol {
         pub use crate::file_ext::async_impl::smol_impl::AsyncFileExt;
